
#include "mycpp/runtime.h"

namespace help_meta {

GLOBAL_STR(gStr1, "all")
GLOBAL_STR(gStr2, "stdlib")
GLOBAL_STR(gStr3, "nq-redir-2")
GLOBAL_STR(gStr4, "Dict/clear")
GLOBAL_STR(gStr5, "type-method")
GLOBAL_STR(gStr6, "redir")
GLOBAL_STR(gStr7, "builtin-cmd")
GLOBAL_STR(gStr8, "ysh:upgrade")
GLOBAL_STR(gStr9, "option")
GLOBAL_STR(gStr10, "sleep")
GLOBAL_STR(gStr11, "boolstatus")
GLOBAL_STR(gStr12, "BoundFunc")
GLOBAL_STR(gStr13, "const")
GLOBAL_STR(gStr14, "ysh-cmd")
GLOBAL_STR(gStr15, "ulimit")
GLOBAL_STR(gStr16, "parseArgs")
GLOBAL_STR(gStr17, "umask")
GLOBAL_STR(gStr18, "LIB_YSH")
GLOBAL_STR(gStr19, "special-var")
GLOBAL_STR(gStr20, "sha256")
GLOBAL_STR(gStr21, "builtin-func")
GLOBAL_STR(gStr22, "setValue")
GLOBAL_STR(gStr23, "RANDOM")
GLOBAL_STR(gStr24, "fromJson8")
GLOBAL_STR(gStr25, "join")
GLOBAL_STR(gStr26, "_group")
GLOBAL_STR(gStr27, "here-doc")
GLOBAL_STR(gStr28, "cmd-lang")
GLOBAL_STR(gStr29, "die")
GLOBAL_STR(gStr30, "_this_dir")
GLOBAL_STR(gStr31, "re-literal")
GLOBAL_STR(gStr32, "expr-lang")
GLOBAL_STR(gStr33, "list")
GLOBAL_STR(gStr34, "ysh-cd")
GLOBAL_STR(gStr35, "try")
GLOBAL_STR(gStr36, "re-compound")
GLOBAL_STR(gStr37, "round")
GLOBAL_STR(gStr38, "strict_nameref")
GLOBAL_STR(gStr39, "BASH_LINENO")
GLOBAL_STR(gStr40, "ascii-control-chars")
GLOBAL_STR(gStr41, "front-end")
GLOBAL_STR(gStr42, "mapfile")
GLOBAL_STR(gStr43, "op-patsub")
GLOBAL_STR(gStr44, "word-lang")
GLOBAL_STR(gStr45, "SHX_indent")
GLOBAL_STR(gStr46, "is-main")
GLOBAL_STR(gStr47, "SIGWINCH")
GLOBAL_STR(gStr48, "plugin")
GLOBAL_STR(gStr49, "bool-str")
GLOBAL_STR(gStr50, "mini-lang")
GLOBAL_STR(gStr51, "op-format")
GLOBAL_STR(gStr52, "setVar")
GLOBAL_STR(gStr53, "append")
GLOBAL_STR(gStr54, "Obj")
GLOBAL_STR(gStr55, "ysh-word-join")
GLOBAL_STR(gStr56, "prefix-binding")
GLOBAL_STR(gStr57, "getFrame")
GLOBAL_STR(gStr58, "COMP_LINE")
GLOBAL_STR(gStr59, "abs")
GLOBAL_STR(gStr60, "ampersand")
GLOBAL_STR(gStr61, "simple-command")
GLOBAL_STR(gStr62, "yb-capture-2")
GLOBAL_STR(gStr63, "SHX_pid_str")
GLOBAL_STR(gStr64, "evalExpr")
GLOBAL_STR(gStr65, "index")
GLOBAL_STR(gStr66, "hash")
GLOBAL_STR(gStr67, "ysh-prefix-binding")
GLOBAL_STR(gStr68, "len")
GLOBAL_STR(gStr69, "b-prefix")
GLOBAL_STR(gStr70, "j8")
GLOBAL_STR(gStr71, "Eggex")
GLOBAL_STR(gStr72, "DEBUG")
GLOBAL_STR(gStr73, "compexport")
GLOBAL_STR(gStr74, "wait")
GLOBAL_STR(gStr75, "sh-array")
GLOBAL_STR(gStr76, "osh-assign")
GLOBAL_STR(gStr77, "search")
GLOBAL_STR(gStr78, "json8-dict")
GLOBAL_STR(gStr79, "fromBase64")
GLOBAL_STR(gStr80, "fat-arrow")
GLOBAL_STR(gStr81, "shift")
GLOBAL_STR(gStr82, "ctx")
GLOBAL_STR(gStr83, "getShFunction")
GLOBAL_STR(gStr84, "Command")
GLOBAL_STR(gStr85, "Null")
GLOBAL_STR(gStr86, "parseHay")
GLOBAL_STR(gStr87, "op-indirect")
GLOBAL_STR(gStr88, "setglobal")
GLOBAL_STR(gStr89, "verbose")
GLOBAL_STR(gStr90, "cmd/type")
GLOBAL_STR(gStr91, "compopt")
GLOBAL_STR(gStr92, "replace")
GLOBAL_STR(gStr93, "PIPESTATUS")
GLOBAL_STR(gStr94, "startup")
GLOBAL_STR(gStr95, "Bool")
GLOBAL_STR(gStr96, "surrogate-pair")
GLOBAL_STR(gStr97, "sha1dc")
GLOBAL_STR(gStr98, "printf")
GLOBAL_STR(gStr99, "HOME")
GLOBAL_STR(gStr100, "_start")
GLOBAL_STR(gStr101, "bindFrame")
GLOBAL_STR(gStr102, "json8")
GLOBAL_STR(gStr103, "regex")
GLOBAL_STR(gStr104, "_process_sub_status")
GLOBAL_STR(gStr105, "use")
GLOBAL_STR(gStr106, "ignore_flags_not_impl")
GLOBAL_STR(gStr107, "runes")
GLOBAL_STR(gStr108, "triple-quoted")
GLOBAL_STR(gStr109, "expr-literal")
GLOBAL_STR(gStr110, "call")
GLOBAL_STR(gStr111, "type")
GLOBAL_STR(gStr112, "until")
GLOBAL_STR(gStr113, "parse_ysh_string")
GLOBAL_STR(gStr114, "CDPATH")
GLOBAL_STR(gStr115, "vm")
GLOBAL_STR(gStr116, "flag")
GLOBAL_STR(gStr117, "ysh-slice")
GLOBAL_STR(gStr118, "osh-usage")
GLOBAL_STR(gStr119, "Str")
GLOBAL_STR(gStr120, "REPLY")
GLOBAL_STR(gStr121, "OILS_GC_ON_EXIT")
GLOBAL_STR(gStr122, "chdir")
GLOBAL_STR(gStr123, "subshell")
GLOBAL_STR(gStr124, "__defaults__")
GLOBAL_STR(gStr125, "Int")
GLOBAL_STR(gStr126, "Frame")
GLOBAL_STR(gStr127, "COMP_ARGV")
GLOBAL_STR(gStr128, "cat")
GLOBAL_STR(gStr129, "values")
GLOBAL_STR(gStr130, "history")
GLOBAL_STR(gStr131, "float-literal")
GLOBAL_STR(gStr132, "encodeRunes")
GLOBAL_STR(gStr133, "io")
GLOBAL_STR(gStr134, "ERR")
GLOBAL_STR(gStr135, "eval_unsafe_arith")
GLOBAL_STR(gStr136, "end")
GLOBAL_STR(gStr137, "redir-file")
GLOBAL_STR(gStr138, "nq-assert")
GLOBAL_STR(gStr139, "write")
GLOBAL_STR(gStr140, "cat-em")
GLOBAL_STR(gStr141, "forkwait")
GLOBAL_STR(gStr142, "config")
GLOBAL_STR(gStr143, "OPTARG")
GLOBAL_STR(gStr144, "INFINITY")
GLOBAL_STR(gStr145, "max")
GLOBAL_STR(gStr146, "op-precedence")
GLOBAL_STR(gStr147, "List")
GLOBAL_STR(gStr148, "dparen")
GLOBAL_STR(gStr149, "fc")
GLOBAL_STR(gStr150, "EUID")
GLOBAL_STR(gStr151, "fg")
GLOBAL_STR(gStr152, "maybe")
GLOBAL_STR(gStr153, "OLDPWD")
GLOBAL_STR(gStr154, "stdin")
GLOBAL_STR(gStr155, "lines")
GLOBAL_STR(gStr156, "nq-run")
GLOBAL_STR(gStr157, "alias")
GLOBAL_STR(gStr158, "LINENO")
GLOBAL_STR(gStr159, "help")
GLOBAL_STR(gStr160, "toJson8")
GLOBAL_STR(gStr161, "trimStart")
GLOBAL_STR(gStr162, "BashArray")
GLOBAL_STR(gStr163, "func/eval")
GLOBAL_STR(gStr164, "Match")
GLOBAL_STR(gStr165, "group")
GLOBAL_STR(gStr166, "ysh-case")
GLOBAL_STR(gStr167, "ysh-attr")
GLOBAL_STR(gStr168, "findLast")
GLOBAL_STR(gStr169, "column-types")
GLOBAL_STR(gStr170, "return")
GLOBAL_STR(gStr171, "aug-assign")
GLOBAL_STR(gStr172, "break")
GLOBAL_STR(gStr173, "bang")
GLOBAL_STR(gStr174, "OPTERR")
GLOBAL_STR(gStr175, "ascii-whitespace")
GLOBAL_STR(gStr176, "__provide__")
GLOBAL_STR(gStr177, "_pipeline_status")
GLOBAL_STR(gStr178, "tagged-str")
GLOBAL_STR(gStr179, "trap")
GLOBAL_STR(gStr180, "BashAssoc")
GLOBAL_STR(gStr181, "match-ops")
GLOBAL_STR(gStr182, "floatsEqual")
GLOBAL_STR(gStr183, "ysh-while")
GLOBAL_STR(gStr184, "IFS")
GLOBAL_STR(gStr185, "ysh-string")
GLOBAL_STR(gStr186, "ysh-chapters")
GLOBAL_STR(gStr187, "PROMPT_COMMAND")
GLOBAL_STR(gStr188, "block-expr")
GLOBAL_STR(gStr189, "bool-expr")
GLOBAL_STR(gStr190, "SHX_punct")
GLOBAL_STR(gStr191, "rm")
GLOBAL_STR(gStr192, "dirs")
GLOBAL_STR(gStr193, "LANG")
GLOBAL_STR(gStr194, "expr/false")
GLOBAL_STR(gStr195, "__builtins__")
GLOBAL_STR(gStr196, "ysh-test")
GLOBAL_STR(gStr197, "int-literal")
GLOBAL_STR(gStr198, "json8-str")
GLOBAL_STR(gStr199, "ENV")
GLOBAL_STR(gStr200, "parseCommand")
GLOBAL_STR(gStr201, "bool-path")
GLOBAL_STR(gStr202, "redir-desc")
GLOBAL_STR(gStr203, "proc-sub")
GLOBAL_STR(gStr204, "times")
GLOBAL_STR(gStr205, "cmd/append")
GLOBAL_STR(gStr206, "toJson")
GLOBAL_STR(gStr207, "sh-arith")
GLOBAL_STR(gStr208, "assign")
GLOBAL_STR(gStr209, "first")
GLOBAL_STR(gStr210, "command-sub")
GLOBAL_STR(gStr211, "re-chars")
GLOBAL_STR(gStr212, "HISTFILE")
GLOBAL_STR(gStr213, "upper")
GLOBAL_STR(gStr214, "histsub")
GLOBAL_STR(gStr215, "echo")
GLOBAL_STR(gStr216, "err-j8-str-encode")
GLOBAL_STR(gStr217, "errors")
GLOBAL_STR(gStr218, "Proc")
GLOBAL_STR(gStr219, "braces")
GLOBAL_STR(gStr220, "SIGQUIT")
GLOBAL_STR(gStr221, "re-capture")
GLOBAL_STR(gStr222, "docComment")
GLOBAL_STR(gStr223, "osh-string")
GLOBAL_STR(gStr224, "ysh-echo")
GLOBAL_STR(gStr225, "ysh-ternary")
GLOBAL_STR(gStr226, "ysh-compare")
GLOBAL_STR(gStr227, "getVar")
GLOBAL_STR(gStr228, "_status")
GLOBAL_STR(gStr229, "OILS_GC_STATS")
GLOBAL_STR(gStr230, "sh-bitwise")
GLOBAL_STR(gStr231, "var-splice")
GLOBAL_STR(gStr232, "osh-chapters")
GLOBAL_STR(gStr233, "List/clear")
GLOBAL_STR(gStr234, "atom-literal")
GLOBAL_STR(gStr235, "var")
GLOBAL_STR(gStr236, "OILS_GC_STATS_FD")
GLOBAL_STR(gStr237, "SHELLOPTS")
GLOBAL_STR(gStr238, "compadjust")
GLOBAL_STR(gStr239, "ysh-equals")
GLOBAL_STR(gStr240, "strict:all")
GLOBAL_STR(gStr241, "FUNCNAME")
GLOBAL_STR(gStr242, "str")
GLOBAL_STR(gStr243, "trimEnd")
GLOBAL_STR(gStr244, "declare")
GLOBAL_STR(gStr245, "and")
GLOBAL_STR(gStr246, "false")
GLOBAL_STR(gStr247, "osh-locale")
GLOBAL_STR(gStr248, "runproc")
GLOBAL_STR(gStr249, "osh-word-join")
GLOBAL_STR(gStr250, "json8-comment")
GLOBAL_STR(gStr251, "PATH")
GLOBAL_STR(gStr252, "null")
GLOBAL_STR(gStr253, "any")
GLOBAL_STR(gStr254, "named-class")
GLOBAL_STR(gStr255, "shvarGet")
GLOBAL_STR(gStr256, "min")
GLOBAL_STR(gStr257, "block-arg")
GLOBAL_STR(gStr258, "json-string")
GLOBAL_STR(gStr259, "xtrace")
GLOBAL_STR(gStr260, "sh-numbers")
GLOBAL_STR(gStr261, "_end")
GLOBAL_STR(gStr262, "j8-escape")
GLOBAL_STR(gStr263, "err-json8-decode")
GLOBAL_STR(gStr264, "exec")
GLOBAL_STR(gStr265, "char-literal")
GLOBAL_STR(gStr266, "glob-pat")
GLOBAL_STR(gStr267, "shSplit")
GLOBAL_STR(gStr268, "leftMatch")
GLOBAL_STR(gStr269, "clear")
GLOBAL_STR(gStr270, "Float")
GLOBAL_STR(gStr271, "renderPrompt")
GLOBAL_STR(gStr272, "typeset")
GLOBAL_STR(gStr273, "pipe")
GLOBAL_STR(gStr274, "ysh-wait")
GLOBAL_STR(gStr275, "opts-redefine")
GLOBAL_STR(gStr276, "re-primitive")
GLOBAL_STR(gStr277, "sum")
GLOBAL_STR(gStr278, "sh-append")
GLOBAL_STR(gStr279, "doc-comment")
GLOBAL_STR(gStr280, "popd")
GLOBAL_STR(gStr281, "__str__")
GLOBAL_STR(gStr282, "func/type")
GLOBAL_STR(gStr283, "opts-internal")
GLOBAL_STR(gStr284, "find")
GLOBAL_STR(gStr285, "op-test")
GLOBAL_STR(gStr286, "command-lookup-order")
GLOBAL_STR(gStr287, "err-j8-str-decode")
GLOBAL_STR(gStr288, "ysh-glob")
GLOBAL_STR(gStr289, "COMP_POINT")
GLOBAL_STR(gStr290, "failed")
GLOBAL_STR(gStr291, "dict")
GLOBAL_STR(gStr292, "__call__")
GLOBAL_STR(gStr293, "local")
GLOBAL_STR(gStr294, "BASH_REMATCH")
GLOBAL_STR(gStr295, "class-literal")
GLOBAL_STR(gStr296, "invoke")
GLOBAL_STR(gStr297, "get")
GLOBAL_STR(gStr298, "ysh-return")
GLOBAL_STR(gStr299, "DebugFrame")
GLOBAL_STR(gStr300, "new")
GLOBAL_STR(gStr301, "dbracket")
GLOBAL_STR(gStr302, "line-editing")
GLOBAL_STR(gStr303, "BASH_SOURCE")
GLOBAL_STR(gStr304, "HOSTNAME")
GLOBAL_STR(gStr305, "bytes")
GLOBAL_STR(gStr306, "remove")
GLOBAL_STR(gStr307, "sourceCode")
GLOBAL_STR(gStr308, "SIGTTIN")
GLOBAL_STR(gStr309, "json-escape")
GLOBAL_STR(gStr310, "set")
GLOBAL_STR(gStr311, "RETURN")
GLOBAL_STR(gStr312, "LIB_OSH")
GLOBAL_STR(gStr313, "parse_triple_quote")
GLOBAL_STR(gStr314, "getopts")
GLOBAL_STR(gStr315, "io/evalExpr")
GLOBAL_STR(gStr316, "lazy-expr-arg")
GLOBAL_STR(gStr317, "re-flags")
GLOBAL_STR(gStr318, "getDebugStack")
GLOBAL_STR(gStr319, "push-registers")
GLOBAL_STR(gStr320, "promptVal")
GLOBAL_STR(gStr321, "arg")
GLOBAL_STR(gStr322, "PS2")
GLOBAL_STR(gStr323, "PS3")
GLOBAL_STR(gStr324, "PS1")
GLOBAL_STR(gStr325, "PS4")
GLOBAL_STR(gStr326, "ysh-func-call")
GLOBAL_STR(gStr327, "bool-infix")
GLOBAL_STR(gStr328, "SECONDS")
GLOBAL_STR(gStr329, "sh-init-list")
GLOBAL_STR(gStr330, "ysh-unary")
GLOBAL_STR(gStr331, "op-strip")
GLOBAL_STR(gStr332, "toString")
GLOBAL_STR(gStr333, "jobs")
GLOBAL_STR(gStr334, "compgen")
GLOBAL_STR(gStr335, "yb-capture")
GLOBAL_STR(gStr336, "oils-usage")
GLOBAL_STR(gStr337, "ysh-trap")
GLOBAL_STR(gStr338, "ysh-printf")
GLOBAL_STR(gStr339, "_reply")
GLOBAL_STR(gStr340, "expr-sub")
GLOBAL_STR(gStr341, "err-utf8-encode")
GLOBAL_STR(gStr342, "err-json-encode")
GLOBAL_STR(gStr343, "reverse")
GLOBAL_STR(gStr344, "ysh-index")
GLOBAL_STR(gStr345, "ysh-arith")
GLOBAL_STR(gStr346, "tilde-sub")
GLOBAL_STR(gStr347, "OILS_GC_THRESHOLD")
GLOBAL_STR(gStr348, "nq-capture")
GLOBAL_STR(gStr349, "fromJson")
GLOBAL_STR(gStr350, "comment")
GLOBAL_STR(gStr351, "captureStdout")
GLOBAL_STR(gStr352, "pop")
GLOBAL_STR(gStr353, "cd")
GLOBAL_STR(gStr354, "extglob")
GLOBAL_STR(gStr355, "colon")
GLOBAL_STR(gStr356, "pp")
GLOBAL_STR(gStr357, "dict-literal")
GLOBAL_STR(gStr358, "source")
GLOBAL_STR(gStr359, "BASHOPTS")
GLOBAL_STR(gStr360, "err-j8-lines-encode")
GLOBAL_STR(gStr361, "SIGINT")
GLOBAL_STR(gStr362, "evalHay")
GLOBAL_STR(gStr363, "haynode")
GLOBAL_STR(gStr364, "json")
GLOBAL_STR(gStr365, "io/eval")
GLOBAL_STR(gStr366, "enable")
GLOBAL_STR(gStr367, "no_parse_ignored")
GLOBAL_STR(gStr368, "OPTIND")
GLOBAL_STR(gStr369, "expr/true")
GLOBAL_STR(gStr370, "assert")
GLOBAL_STR(gStr371, "func")
GLOBAL_STR(gStr372, "sh-block")
GLOBAL_STR(gStr373, "BuiltinProc")
GLOBAL_STR(gStr374, "osh-glob")
GLOBAL_STR(gStr375, "case")
GLOBAL_STR(gStr376, "encodeBytes")
GLOBAL_STR(gStr377, "while")
GLOBAL_STR(gStr378, "BuiltinFunc")
GLOBAL_STR(gStr379, "error")
GLOBAL_STR(gStr380, "readarray")
GLOBAL_STR(gStr381, "PPID")
GLOBAL_STR(gStr382, "shopt")
GLOBAL_STR(gStr383, "re-splice")
GLOBAL_STR(gStr384, "equal")
GLOBAL_STR(gStr385, "Dict")
GLOBAL_STR(gStr386, "extdebug")
GLOBAL_STR(gStr387, "no-prefix")
GLOBAL_STR(gStr388, "OILS_LOCALE_OK")
GLOBAL_STR(gStr389, "id")
GLOBAL_STR(gStr390, "GLOBIGNORE")
GLOBAL_STR(gStr391, "if")
GLOBAL_STR(gStr392, "cmd/false")
GLOBAL_STR(gStr393, "line-continuation")
GLOBAL_STR(gStr394, "ysh-usage")
GLOBAL_STR(gStr395, "read")
GLOBAL_STR(gStr396, "split")
GLOBAL_STR(gStr397, "strict_control_flow")
GLOBAL_STR(gStr398, "json8-list")
GLOBAL_STR(gStr399, "err-j8-lines-decode")
GLOBAL_STR(gStr400, "ysh-read")
GLOBAL_STR(gStr401, "keys")
GLOBAL_STR(gStr402, "Expr")
GLOBAL_STR(gStr403, "str-template")
GLOBAL_STR(gStr404, "ysh-format")
GLOBAL_STR(gStr405, "errtrace")
GLOBAL_STR(gStr406, "lower")
GLOBAL_STR(gStr407, "strict_tilde")
GLOBAL_STR(gStr408, "COMPREPLY")
GLOBAL_STR(gStr409, "PWD")
GLOBAL_STR(gStr410, "command")
GLOBAL_STR(gStr411, "strftime")
GLOBAL_STR(gStr412, "sh-func")
GLOBAL_STR(gStr413, "err-json-decode")
GLOBAL_STR(gStr414, "NAN")
GLOBAL_STR(gStr415, "rest")
GLOBAL_STR(gStr416, "kill")
GLOBAL_STR(gStr417, "err-utf8-decode")
GLOBAL_STR(gStr418, "source-guard")
GLOBAL_STR(gStr419, "UID")
GLOBAL_STR(gStr420, "u-prefix")
GLOBAL_STR(gStr421, "builtin")
GLOBAL_STR(gStr422, "hay")
GLOBAL_STR(gStr423, "rewrite_extern")
GLOBAL_STR(gStr424, "re-multiline")
GLOBAL_STR(gStr425, "sh-assign")
GLOBAL_STR(gStr426, "command-splice")
GLOBAL_STR(gStr427, "shell-flags")
GLOBAL_STR(gStr428, "sh-assoc")
GLOBAL_STR(gStr429, "insert")
GLOBAL_STR(gStr430, "_error")
GLOBAL_STR(gStr431, "COMP_CWORD")
GLOBAL_STR(gStr432, "ysh-locale")
GLOBAL_STR(gStr433, "continue")
GLOBAL_STR(gStr434, "task-five")
GLOBAL_STR(gStr435, "OILS_VERSION")
GLOBAL_STR(gStr436, "strcmp")
GLOBAL_STR(gStr437, "toBase16")
GLOBAL_STR(gStr438, "json8-num")
GLOBAL_STR(gStr439, "ARGV")
GLOBAL_STR(gStr440, "erase")
GLOBAL_STR(gStr441, "export")
GLOBAL_STR(gStr442, "pushd")
GLOBAL_STR(gStr443, "YSH_HISTFILE")
GLOBAL_STR(gStr444, "startsWith")
GLOBAL_STR(gStr445, "dashglob")
GLOBAL_STR(gStr446, "for")
GLOBAL_STR(gStr447, "thin-arrow")
GLOBAL_STR(gStr448, "parseExpr")
GLOBAL_STR(gStr449, "exit")
GLOBAL_STR(gStr450, "Func")
GLOBAL_STR(gStr451, "captureAll")
GLOBAL_STR(gStr452, "typed-arg")
GLOBAL_STR(gStr453, "nq-capture-2")
GLOBAL_STR(gStr454, "proc")
GLOBAL_STR(gStr455, "glob")
GLOBAL_STR(gStr456, "ysh-in")
GLOBAL_STR(gStr457, "bg")
GLOBAL_STR(gStr458, "arith-sub")
GLOBAL_STR(gStr459, "indexOf")
GLOBAL_STR(gStr460, "ysh-if")
GLOBAL_STR(gStr461, "expr-splice")
GLOBAL_STR(gStr462, "Range")
GLOBAL_STR(gStr463, "Place")
GLOBAL_STR(gStr464, "OILS_COMP_UI")
GLOBAL_STR(gStr465, "nq-redir")
GLOBAL_STR(gStr466, "ysh-shopt")
GLOBAL_STR(gStr467, "ysh-for")
GLOBAL_STR(gStr468, "range")
GLOBAL_STR(gStr469, "BASHPID")
GLOBAL_STR(gStr470, "or")
GLOBAL_STR(gStr471, "contains")
GLOBAL_STR(gStr472, "float")
GLOBAL_STR(gStr473, "cmd/eval")
GLOBAL_STR(gStr474, "list-literal")
GLOBAL_STR(gStr475, "for-expr-sh")
GLOBAL_STR(gStr476, "cmd/true")
GLOBAL_STR(gStr477, "column-attrs")
GLOBAL_STR(gStr478, "here-str")
GLOBAL_STR(gStr479, "log")
GLOBAL_STR(gStr480, "shvar")
GLOBAL_STR(gStr481, "op-bracket")
GLOBAL_STR(gStr482, "start")
GLOBAL_STR(gStr483, "__sh_function__")
GLOBAL_STR(gStr484, "OSTYPE")
GLOBAL_STR(gStr485, "sh-logical")
GLOBAL_STR(gStr486, "fork")
GLOBAL_STR(gStr487, "complete")
GLOBAL_STR(gStr488, "ysh:all")
GLOBAL_STR(gStr489, "ysh-logical")
GLOBAL_STR(gStr490, "COMP_WORDBREAKS")
GLOBAL_STR(gStr491, "pwd")
GLOBAL_STR(gStr492, "SIGTERM")
GLOBAL_STR(gStr493, "true")
GLOBAL_STR(gStr494, "fromBase16")
GLOBAL_STR(gStr495, "extend")
GLOBAL_STR(gStr496, "exit-codes")
GLOBAL_STR(gStr497, "syntax-tree")
GLOBAL_STR(gStr498, "ignore_shopt_not_impl")
GLOBAL_STR(gStr499, "EXIT")
GLOBAL_STR(gStr500, "err-json8-encode")
GLOBAL_STR(gStr501, "re-repeat")
GLOBAL_STR(gStr502, "trim")
GLOBAL_STR(gStr503, "semicolon")
GLOBAL_STR(gStr504, "int")
GLOBAL_STR(gStr505, "parser")
GLOBAL_STR(gStr506, "op-slice")
GLOBAL_STR(gStr507, "ysh-bitwise")
GLOBAL_STR(gStr508, "nullglob")
GLOBAL_STR(gStr509, "inc")
GLOBAL_STR(gStr510, "arith-context")
GLOBAL_STR(gStr511, "unquoted-line")
GLOBAL_STR(gStr512, "func/evalExpr")
GLOBAL_STR(gStr513, "unalias")
GLOBAL_STR(gStr514, "__invoke__")
GLOBAL_STR(gStr515, "readonly")
GLOBAL_STR(gStr516, "bool")
GLOBAL_STR(gStr517, "test")
GLOBAL_STR(gStr518, "setvar")
GLOBAL_STR(gStr519, "COMP_WORDS")
GLOBAL_STR(gStr520, "repeat")
GLOBAL_STR(gStr521, "lastIndexOf")
GLOBAL_STR(gStr522, "toBase64")
GLOBAL_STR(gStr523, "eval")
GLOBAL_STR(gStr524, "ysh-here-str")
GLOBAL_STR(gStr525, "concat")
GLOBAL_STR(gStr526, "List/append")
GLOBAL_STR(gStr527, "char-escapes")
GLOBAL_STR(gStr528, "var-sub")
GLOBAL_STR(gStr529, "bool-other")
GLOBAL_STR(gStr530, "endsWith")
GLOBAL_STR(gStr531, "multiline-command")
GLOBAL_STR(gStr532, "time")
GLOBAL_STR(gStr533, "sigpipe_status_ok")
GLOBAL_STR(gStr534, "__index__")
GLOBAL_STR(gStr535, "SIGTTOU")
GLOBAL_STR(gStr536, "unset")

GLOBAL_DICT(gTopics, BigStr*, BigStr*, 519, {gStr1 COMMA gStr3 COMMA gStr4 COMMA gStr6 COMMA gStr8 COMMA gStr10 COMMA gStr11 COMMA gStr12 COMMA gStr13 COMMA gStr15 COMMA gStr16 COMMA gStr17 COMMA gStr18 COMMA gStr20 COMMA gStr22 COMMA gStr23 COMMA gStr24 COMMA gStr25 COMMA gStr26 COMMA gStr27 COMMA gStr29 COMMA gStr30 COMMA gStr31 COMMA gStr33 COMMA gStr34 COMMA gStr35 COMMA gStr36 COMMA gStr37 COMMA gStr38 COMMA gStr39 COMMA gStr40 COMMA gStr42 COMMA gStr43 COMMA gStr45 COMMA gStr46 COMMA gStr47 COMMA gStr49 COMMA gStr51 COMMA gStr52 COMMA gStr53 COMMA gStr54 COMMA gStr55 COMMA gStr56 COMMA gStr57 COMMA gStr58 COMMA gStr59 COMMA gStr60 COMMA gStr61 COMMA gStr62 COMMA gStr63 COMMA gStr64 COMMA gStr66 COMMA gStr67 COMMA gStr68 COMMA gStr69 COMMA gStr71 COMMA gStr72 COMMA gStr73 COMMA gStr74 COMMA gStr75 COMMA gStr77 COMMA gStr78 COMMA gStr79 COMMA gStr80 COMMA gStr81 COMMA gStr82 COMMA gStr83 COMMA gStr84 COMMA gStr85 COMMA gStr86 COMMA gStr87 COMMA gStr88 COMMA gStr89 COMMA gStr90 COMMA gStr91 COMMA gStr92 COMMA gStr93 COMMA gStr94 COMMA gStr95 COMMA gStr96 COMMA gStr97 COMMA gStr98 COMMA gStr99 COMMA gStr100 COMMA gStr101 COMMA gStr102 COMMA gStr103 COMMA gStr104 COMMA gStr105 COMMA gStr106 COMMA gStr107 COMMA gStr108 COMMA gStr109 COMMA gStr110 COMMA gStr111 COMMA gStr112 COMMA gStr113 COMMA gStr114 COMMA gStr115 COMMA gStr116 COMMA gStr117 COMMA gStr118 COMMA gStr119 COMMA gStr120 COMMA gStr121 COMMA gStr122 COMMA gStr123 COMMA gStr124 COMMA gStr125 COMMA gStr126 COMMA gStr127 COMMA gStr128 COMMA gStr129 COMMA gStr130 COMMA gStr131 COMMA gStr132 COMMA gStr133 COMMA gStr134 COMMA gStr135 COMMA gStr136 COMMA gStr137 COMMA gStr138 COMMA gStr139 COMMA gStr140 COMMA gStr141 COMMA gStr142 COMMA gStr143 COMMA gStr144 COMMA gStr145 COMMA gStr146 COMMA gStr147 COMMA gStr148 COMMA gStr149 COMMA gStr150 COMMA gStr151 COMMA gStr152 COMMA gStr153 COMMA gStr154 COMMA gStr155 COMMA gStr156 COMMA gStr157 COMMA gStr158 COMMA gStr159 COMMA gStr160 COMMA gStr161 COMMA gStr162 COMMA gStr163 COMMA gStr164 COMMA gStr165 COMMA gStr166 COMMA gStr167 COMMA gStr168 COMMA gStr169 COMMA gStr170 COMMA gStr171 COMMA gStr172 COMMA gStr173 COMMA gStr174 COMMA gStr175 COMMA gStr176 COMMA gStr177 COMMA gStr178 COMMA gStr179 COMMA gStr180 COMMA gStr181 COMMA gStr182 COMMA gStr183 COMMA gStr184 COMMA gStr185 COMMA gStr186 COMMA gStr187 COMMA gStr188 COMMA gStr189 COMMA gStr190 COMMA gStr191 COMMA gStr192 COMMA gStr193 COMMA gStr194 COMMA gStr195 COMMA gStr196 COMMA gStr197 COMMA gStr198 COMMA gStr199 COMMA gStr200 COMMA gStr201 COMMA gStr202 COMMA gStr203 COMMA gStr204 COMMA gStr205 COMMA gStr206 COMMA gStr207 COMMA gStr208 COMMA gStr209 COMMA gStr210 COMMA gStr211 COMMA gStr212 COMMA gStr213 COMMA gStr214 COMMA gStr215 COMMA gStr216 COMMA gStr218 COMMA gStr219 COMMA gStr220 COMMA gStr221 COMMA gStr222 COMMA gStr223 COMMA gStr224 COMMA gStr225 COMMA gStr226 COMMA gStr227 COMMA gStr228 COMMA gStr229 COMMA gStr230 COMMA gStr231 COMMA gStr232 COMMA gStr233 COMMA gStr234 COMMA gStr235 COMMA gStr236 COMMA gStr237 COMMA gStr238 COMMA gStr239 COMMA gStr240 COMMA gStr241 COMMA gStr242 COMMA gStr243 COMMA gStr244 COMMA gStr245 COMMA gStr246 COMMA gStr247 COMMA gStr248 COMMA gStr249 COMMA gStr250 COMMA gStr251 COMMA gStr252 COMMA gStr253 COMMA gStr254 COMMA gStr255 COMMA gStr256 COMMA gStr257 COMMA gStr258 COMMA gStr259 COMMA gStr260 COMMA gStr261 COMMA gStr262 COMMA gStr263 COMMA gStr264 COMMA gStr265 COMMA gStr266 COMMA gStr267 COMMA gStr268 COMMA gStr269 COMMA gStr270 COMMA gStr271 COMMA gStr272 COMMA gStr273 COMMA gStr274 COMMA gStr275 COMMA gStr276 COMMA gStr277 COMMA gStr278 COMMA gStr279 COMMA gStr280 COMMA gStr281 COMMA gStr282 COMMA gStr283 COMMA gStr284 COMMA gStr285 COMMA gStr286 COMMA gStr287 COMMA gStr288 COMMA gStr289 COMMA gStr290 COMMA gStr291 COMMA gStr292 COMMA gStr293 COMMA gStr294 COMMA gStr295 COMMA gStr296 COMMA gStr297 COMMA gStr298 COMMA gStr299 COMMA gStr300 COMMA gStr301 COMMA gStr302 COMMA gStr303 COMMA gStr304 COMMA gStr305 COMMA gStr306 COMMA gStr307 COMMA gStr308 COMMA gStr309 COMMA gStr310 COMMA gStr311 COMMA gStr312 COMMA gStr313 COMMA gStr314 COMMA gStr315 COMMA gStr316 COMMA gStr317 COMMA gStr318 COMMA gStr319 COMMA gStr320 COMMA gStr321 COMMA gStr322 COMMA gStr323 COMMA gStr324 COMMA gStr325 COMMA gStr326 COMMA gStr327 COMMA gStr328 COMMA gStr329 COMMA gStr330 COMMA gStr331 COMMA gStr332 COMMA gStr333 COMMA gStr334 COMMA gStr335 COMMA gStr336 COMMA gStr337 COMMA gStr338 COMMA gStr339 COMMA gStr340 COMMA gStr341 COMMA gStr342 COMMA gStr343 COMMA gStr344 COMMA gStr345 COMMA gStr346 COMMA gStr347 COMMA gStr348 COMMA gStr349 COMMA gStr350 COMMA gStr351 COMMA gStr352 COMMA gStr353 COMMA gStr354 COMMA gStr355 COMMA gStr356 COMMA gStr357 COMMA gStr358 COMMA gStr359 COMMA gStr360 COMMA gStr361 COMMA gStr362 COMMA gStr363 COMMA gStr364 COMMA gStr365 COMMA gStr366 COMMA gStr367 COMMA gStr368 COMMA gStr369 COMMA gStr370 COMMA gStr371 COMMA gStr372 COMMA gStr373 COMMA gStr374 COMMA gStr375 COMMA gStr376 COMMA gStr377 COMMA gStr378 COMMA gStr379 COMMA gStr380 COMMA gStr381 COMMA gStr382 COMMA gStr383 COMMA gStr384 COMMA gStr385 COMMA gStr386 COMMA gStr387 COMMA gStr388 COMMA gStr389 COMMA gStr390 COMMA gStr391 COMMA gStr392 COMMA gStr393 COMMA gStr394 COMMA gStr395 COMMA gStr396 COMMA gStr397 COMMA gStr398 COMMA gStr399 COMMA gStr400 COMMA gStr401 COMMA gStr402 COMMA gStr403 COMMA gStr404 COMMA gStr405 COMMA gStr406 COMMA gStr407 COMMA gStr408 COMMA gStr409 COMMA gStr410 COMMA gStr411 COMMA gStr412 COMMA gStr413 COMMA gStr414 COMMA gStr415 COMMA gStr416 COMMA gStr417 COMMA gStr418 COMMA gStr419 COMMA gStr420 COMMA gStr421 COMMA gStr422 COMMA gStr423 COMMA gStr424 COMMA gStr425 COMMA gStr426 COMMA gStr427 COMMA gStr428 COMMA gStr429 COMMA gStr430 COMMA gStr431 COMMA gStr432 COMMA gStr433 COMMA gStr434 COMMA gStr435 COMMA gStr436 COMMA gStr437 COMMA gStr438 COMMA gStr439 COMMA gStr440 COMMA gStr441 COMMA gStr442 COMMA gStr443 COMMA gStr444 COMMA gStr445 COMMA gStr446 COMMA gStr447 COMMA gStr448 COMMA gStr449 COMMA gStr450 COMMA gStr451 COMMA gStr452 COMMA gStr453 COMMA gStr454 COMMA gStr455 COMMA gStr456 COMMA gStr457 COMMA gStr458 COMMA gStr459 COMMA gStr460 COMMA gStr461 COMMA gStr462 COMMA gStr463 COMMA gStr464 COMMA gStr465 COMMA gStr466 COMMA gStr467 COMMA gStr468 COMMA gStr469 COMMA gStr470 COMMA gStr471 COMMA gStr472 COMMA gStr473 COMMA gStr474 COMMA gStr475 COMMA gStr476 COMMA gStr477 COMMA gStr478 COMMA gStr479 COMMA gStr480 COMMA gStr481 COMMA gStr482 COMMA gStr483 COMMA gStr484 COMMA gStr485 COMMA gStr486 COMMA gStr487 COMMA gStr488 COMMA gStr489 COMMA gStr490 COMMA gStr491 COMMA gStr492 COMMA gStr493 COMMA gStr494 COMMA gStr495 COMMA gStr496 COMMA gStr497 COMMA gStr498 COMMA gStr499 COMMA gStr500 COMMA gStr501 COMMA gStr502 COMMA gStr503 COMMA gStr504 COMMA gStr505 COMMA gStr506 COMMA gStr507 COMMA gStr508 COMMA gStr509 COMMA gStr510 COMMA gStr511 COMMA gStr512 COMMA gStr513 COMMA gStr514 COMMA gStr515 COMMA gStr516 COMMA gStr517 COMMA gStr518 COMMA gStr519 COMMA gStr520 COMMA gStr521 COMMA gStr522 COMMA gStr523 COMMA gStr524 COMMA gStr525 COMMA gStr526 COMMA gStr527 COMMA gStr528 COMMA gStr529 COMMA gStr530 COMMA gStr531 COMMA gStr532 COMMA gStr533 COMMA gStr534 COMMA gStr535 COMMA gStr536}, {gStr2 COMMA gStr2 COMMA gStr5 COMMA gStr7 COMMA gStr9 COMMA gStr7 COMMA gStr7 COMMA gStr5 COMMA gStr14 COMMA gStr7 COMMA gStr2 COMMA gStr7 COMMA gStr19 COMMA gStr21 COMMA gStr5 COMMA gStr19 COMMA gStr21 COMMA gStr21 COMMA gStr21 COMMA gStr28 COMMA gStr2 COMMA gStr19 COMMA gStr32 COMMA gStr21 COMMA gStr7 COMMA gStr7 COMMA gStr32 COMMA gStr2 COMMA gStr9 COMMA gStr19 COMMA gStr41 COMMA gStr7 COMMA gStr44 COMMA gStr19 COMMA gStr7 COMMA gStr48 COMMA gStr50 COMMA gStr44 COMMA gStr21 COMMA gStr5 COMMA gStr5 COMMA gStr44 COMMA gStr28 COMMA gStr5 COMMA gStr19 COMMA gStr2 COMMA gStr28 COMMA gStr28 COMMA gStr2 COMMA gStr19 COMMA gStr65 COMMA gStr7 COMMA gStr28 COMMA gStr21 COMMA gStr70 COMMA gStr5 COMMA gStr48 COMMA gStr7 COMMA gStr7 COMMA gStr76 COMMA gStr5 COMMA gStr70 COMMA gStr2 COMMA gStr32 COMMA gStr76 COMMA gStr7 COMMA gStr21 COMMA gStr5 COMMA gStr5 COMMA gStr21 COMMA gStr44 COMMA gStr14 COMMA gStr9 COMMA gStr7 COMMA gStr7 COMMA gStr5 COMMA gStr19 COMMA gStr41 COMMA gStr5 COMMA gStr70 COMMA gStr21 COMMA gStr7 COMMA gStr19 COMMA gStr21 COMMA gStr21 COMMA gStr7 COMMA gStr50 COMMA gStr19 COMMA gStr7 COMMA gStr9 COMMA gStr21 COMMA gStr44 COMMA gStr32 COMMA gStr14 COMMA gStr65 COMMA gStr28 COMMA gStr9 COMMA gStr19 COMMA gStr5 COMMA gStr2 COMMA gStr32 COMMA nullptr COMMA gStr5 COMMA gStr19 COMMA gStr19 COMMA gStr7 COMMA gStr28 COMMA gStr19 COMMA gStr5 COMMA gStr5 COMMA gStr19 COMMA gStr7 COMMA gStr21 COMMA gStr7 COMMA gStr32 COMMA gStr21 COMMA gStr5 COMMA gStr48 COMMA gStr9 COMMA gStr5 COMMA gStr28 COMMA gStr2 COMMA gStr7 COMMA gStr41 COMMA gStr7 COMMA gStr41 COMMA gStr19 COMMA gStr19 COMMA gStr2 COMMA gStr32 COMMA gStr5 COMMA gStr28 COMMA gStr7 COMMA gStr19 COMMA gStr7 COMMA gStr21 COMMA gStr19 COMMA gStr5 COMMA gStr5 COMMA gStr2 COMMA gStr7 COMMA gStr19 COMMA nullptr COMMA gStr21 COMMA gStr5 COMMA gStr5 COMMA gStr21 COMMA gStr5 COMMA gStr5 COMMA gStr28 COMMA gStr32 COMMA gStr5 COMMA gStr70 COMMA gStr28 COMMA gStr32 COMMA gStr28 COMMA gStr28 COMMA gStr19 COMMA gStr41 COMMA gStr19 COMMA gStr19 COMMA gStr44 COMMA gStr7 COMMA gStr5 COMMA gStr32 COMMA gStr21 COMMA gStr28 COMMA gStr19 COMMA gStr44 COMMA nullptr COMMA gStr48 COMMA gStr32 COMMA gStr50 COMMA gStr19 COMMA gStr7 COMMA gStr7 COMMA gStr19 COMMA gStr5 COMMA gStr19 COMMA gStr7 COMMA gStr32 COMMA gStr70 COMMA gStr19 COMMA gStr21 COMMA gStr50 COMMA gStr28 COMMA gStr44 COMMA gStr7 COMMA gStr7 COMMA gStr21 COMMA gStr50 COMMA gStr32 COMMA gStr21 COMMA gStr44 COMMA gStr32 COMMA gStr19 COMMA gStr5 COMMA gStr50 COMMA gStr7 COMMA gStr217 COMMA gStr5 COMMA gStr50 COMMA gStr48 COMMA gStr32 COMMA gStr5 COMMA gStr44 COMMA gStr7 COMMA gStr32 COMMA gStr32 COMMA gStr21 COMMA gStr19 COMMA gStr19 COMMA gStr50 COMMA gStr44 COMMA nullptr COMMA gStr5 COMMA gStr32 COMMA gStr14 COMMA gStr19 COMMA gStr19 COMMA gStr7 COMMA gStr32 COMMA gStr9 COMMA gStr19 COMMA gStr21 COMMA gStr5 COMMA gStr76 COMMA gStr28 COMMA gStr65 COMMA gStr19 COMMA gStr7 COMMA gStr44 COMMA gStr70 COMMA gStr19 COMMA gStr5 COMMA gStr2 COMMA gStr32 COMMA gStr21 COMMA gStr2 COMMA gStr28 COMMA gStr70 COMMA gStr9 COMMA gStr50 COMMA gStr21 COMMA gStr70 COMMA gStr217 COMMA gStr7 COMMA gStr32 COMMA gStr50 COMMA gStr21 COMMA gStr5 COMMA gStr65 COMMA gStr5 COMMA gStr48 COMMA gStr76 COMMA gStr28 COMMA gStr7 COMMA gStr9 COMMA gStr32 COMMA gStr2 COMMA gStr76 COMMA gStr41 COMMA gStr7 COMMA gStr5 COMMA gStr21 COMMA gStr9 COMMA gStr5 COMMA gStr44 COMMA gStr28 COMMA gStr217 COMMA gStr44 COMMA gStr19 COMMA gStr7 COMMA gStr21 COMMA gStr5 COMMA gStr76 COMMA gStr19 COMMA gStr32 COMMA gStr7 COMMA gStr21 COMMA gStr14 COMMA gStr5 COMMA gStr5 COMMA gStr28 COMMA gStr41 COMMA gStr19 COMMA gStr19 COMMA gStr21 COMMA gStr5 COMMA gStr5 COMMA gStr48 COMMA gStr70 COMMA gStr7 COMMA gStr48 COMMA gStr19 COMMA gStr9 COMMA gStr7 COMMA gStr5 COMMA gStr28 COMMA gStr32 COMMA gStr5 COMMA gStr7 COMMA gStr5 COMMA gStr2 COMMA gStr48 COMMA gStr48 COMMA gStr48 COMMA gStr48 COMMA gStr32 COMMA gStr50 COMMA gStr19 COMMA gStr76 COMMA gStr32 COMMA gStr44 COMMA gStr5 COMMA gStr7 COMMA gStr7 COMMA gStr2 COMMA nullptr COMMA gStr7 COMMA gStr44 COMMA gStr19 COMMA gStr44 COMMA gStr217 COMMA gStr217 COMMA gStr5 COMMA gStr32 COMMA gStr32 COMMA gStr44 COMMA gStr19 COMMA gStr2 COMMA gStr21 COMMA gStr41 COMMA gStr5 COMMA gStr5 COMMA gStr7 COMMA gStr50 COMMA gStr7 COMMA gStr7 COMMA gStr32 COMMA gStr7 COMMA gStr19 COMMA gStr217 COMMA gStr48 COMMA gStr21 COMMA gStr7 COMMA gStr7 COMMA gStr5 COMMA gStr7 COMMA gStr9 COMMA gStr19 COMMA gStr5 COMMA gStr7 COMMA gStr14 COMMA gStr28 COMMA gStr5 COMMA gStr44 COMMA gStr28 COMMA gStr21 COMMA gStr28 COMMA gStr5 COMMA gStr7 COMMA gStr7 COMMA gStr19 COMMA gStr7 COMMA gStr32 COMMA gStr14 COMMA gStr5 COMMA gStr9 COMMA gStr70 COMMA gStr19 COMMA gStr5 COMMA gStr19 COMMA gStr28 COMMA gStr7 COMMA gStr41 COMMA nullptr COMMA gStr7 COMMA gStr5 COMMA gStr9 COMMA gStr70 COMMA gStr217 COMMA gStr7 COMMA gStr21 COMMA gStr5 COMMA gStr32 COMMA gStr44 COMMA gStr9 COMMA gStr5 COMMA gStr9 COMMA gStr19 COMMA gStr19 COMMA gStr7 COMMA gStr5 COMMA gStr28 COMMA gStr217 COMMA gStr19 COMMA gStr2 COMMA gStr7 COMMA gStr217 COMMA gStr7 COMMA gStr19 COMMA gStr70 COMMA gStr7 COMMA gStr7 COMMA gStr9 COMMA gStr32 COMMA gStr76 COMMA gStr44 COMMA nullptr COMMA gStr76 COMMA gStr5 COMMA gStr19 COMMA gStr19 COMMA gStr19 COMMA gStr28 COMMA gStr2 COMMA gStr19 COMMA gStr21 COMMA gStr2 COMMA gStr70 COMMA gStr19 COMMA gStr5 COMMA gStr76 COMMA gStr7 COMMA gStr19 COMMA gStr5 COMMA gStr9 COMMA gStr28 COMMA gStr32 COMMA gStr21 COMMA gStr28 COMMA gStr5 COMMA gStr5 COMMA gStr28 COMMA gStr2 COMMA gStr14 COMMA gStr5 COMMA gStr32 COMMA gStr7 COMMA gStr44 COMMA gStr5 COMMA gStr28 COMMA gStr44 COMMA gStr5 COMMA gStr5 COMMA gStr19 COMMA gStr2 COMMA gStr7 COMMA gStr28 COMMA gStr32 COMMA gStr19 COMMA gStr28 COMMA gStr5 COMMA gStr21 COMMA gStr7 COMMA gStr32 COMMA gStr28 COMMA gStr7 COMMA gStr70 COMMA gStr28 COMMA gStr2 COMMA gStr7 COMMA gStr44 COMMA gStr5 COMMA gStr19 COMMA gStr19 COMMA gStr50 COMMA gStr7 COMMA gStr48 COMMA gStr9 COMMA gStr32 COMMA gStr19 COMMA gStr7 COMMA gStr48 COMMA gStr65 COMMA gStr2 COMMA gStr5 COMMA gStr41 COMMA gStr41 COMMA gStr9 COMMA gStr48 COMMA gStr217 COMMA gStr32 COMMA gStr5 COMMA gStr28 COMMA gStr21 COMMA gStr2 COMMA gStr44 COMMA gStr32 COMMA gStr9 COMMA gStr5 COMMA gStr50 COMMA gStr70 COMMA gStr21 COMMA gStr7 COMMA gStr5 COMMA gStr76 COMMA gStr21 COMMA gStr7 COMMA gStr14 COMMA gStr19 COMMA gStr2 COMMA gStr5 COMMA gStr2 COMMA gStr65 COMMA gStr28 COMMA gStr32 COMMA gStr5 COMMA gStr50 COMMA gStr44 COMMA gStr50 COMMA gStr5 COMMA gStr41 COMMA gStr5 COMMA gStr9 COMMA gStr5 COMMA gStr48 COMMA gStr76});

Dict<BigStr*, BigStr*>* TopicMetadata() {
  return gTopics;
}
}
